The Aloha Editor Boilerplate - Just another demo page

Loading Aloha Editor

The Aloha Boilerplate.

- ## Formatting

  Bold, headlines, ...

  Bold or headlines, whatever you might want

  ## Formatting content

  Editing any content with Aloha Editor is similar to editing with state of the art word processors on your desktop. No need to learn any HTML, Wiki or other markup language. The option dialogs have been designed for users not for techies. Writing content has never been that easy.

  More about content formatting

- ## Images

  Placing, scaling ...

  ### Place and edit images with Aloha

  ## Image-Editing

  Editing any content with Aloha Editor is similar to editing with state of the art word processors on your desktop. No need to learn any HTML, Wiki or other markup language. The option dialogs have been designed for users not for techies. Writing content has never been that easy.

  Digg into placing/editing of images

- ## Tables

  All you might put into tables

  ### Create and edit tables the way you want them to be

  ## Table Stuff

  Editing any content with Aloha Editor is similar to editing with state of the art word processors on your desktop. No need to learn any HTML, Wiki or other markup language. The option dialogs have been designed for users not for techies. Writing content has never been that easy.

  Try out table editing

- ## Boxes

  You may edit dynamic boxes

  ### You can edit dynamic content

  ## Edit jQuery stuff

  Your imagination ist the limit. Edit every content even if it is dynamic.

  Try out jQuery boxes

- ## Comments

  threaded inline comments

  ### Threaded inline enterprise commenting

  ## Increase collaboration

  Your imagination ist the limit. Does more content fill the box and move it to the right?

  Try out jQuery boxes

Here you'll find some example content to show Aloha's possibilities regarding any kind of formatting.

# Headline 1

## Headline 2

### Headline 3

#### Headline 4

##### Headline 5

###### Headline 6

Here we test, a link and other formattings such as bold, italic or deleted text. You may also use formattings for maths 2 2 = 4 or chemical formulas like CO2. Or you may edit tables as you do in office products.

This | is | a | demo
table | with | an
awesome | column
and | row | span | !
describe the table

To describe code you would use fixed style pre

    <script>
    	// make content editable
    	$('#content').aloha();
    	$('.top-text').aloha();
    </script>

- List entry
  - List entry
  - List entry
    - List entry
    - List entry
- List entry
- List entry
- List entry

1. List entry
   1. List entry
   2. List entry
      1. List entry
      2. List entry
2. List entry
3. List entry
4. List entry

For better sematical understanding and WAI compatibility you can describe abbreviations like HTML and CSS.

More Demos: http://aloha-editor.org/demos/

· Ask a question
· Read the guides
· Report an issue
Aloha Editor website